const API = require("../../lib/API")
const db = require("../../plugin/DataBase/db")
const AccessControl = require("../../lib/AccessControl")
const { BaseStdResponse } = require("../../BaseStdResponse")

class GetAIChatMessages extends API {
    constructor() {
        super()

        this.setPath('/AI/GetAIChatMessages')
        this.setMethod('GET')
    }

    async onRequest(req, res) {
        let { uuid, session } = req.query
        if ([uuid, session].some(value => value === '' || value === null || value === undefined))
            return res.json({
                ...BaseStdResponse.MISSING_PARAMETER
            })

        // 检查 session
        if (!await AccessControl.checkSession(uuid, session))
            return res.status(401).json({
                ...BaseStdResponse.ACCESS_DENIED
            })

        let sql = 'SELECT content, time, type, \`read\` FROM messages WHERE uuid = ?'
        let rows = await db.query(sql, [uuid])

        if (!rows || rows.length === 0)
            return res.json({
                ...BaseStdResponse.OK,
                data: []
            })

        res.json({
            ...BaseStdResponse.OK,
            data: rows
        })

    }
}

module.exports.GetAIChatMessages = GetAIChatMessages